@@ -1,3 +1,5 @@
+from collections import defaultdict
+
 import taskcluster
 from taskcluster.exceptions import TaskclusterRestFailure
 
@@ -10,6 +12,30 @@ def get_pools(only_pools=None):
     return [p for p in pools if not only_pools or p["workerPoolId"] in only_pools]
 
 
+def get_images(**pool_args):
+    pools_by_image = defaultdict(set)
+    for pool in get_pools(**pool_args):
+        if not pool["config"]:
+            continue
+
+        images = set()
+        for launch_config in pool["config"]["launchConfigs"]:
+            if pool["providerId"] == "aws":
+                images.add(launch_config["launchConfig"]["ImageId"])
+
+            elif pool["providerId"].endswith("gcp"):
+                for launch_config in pool["config"]["launchConfigs"]:
+                    for disk in launch_config["disks"]:
+                        if not disk.get("boot"):
+                            continue
+                        images.add(disk["initializeParams"]["sourceImage"])
+
+        for image in images:
+            pools_by_image[image].add(pool["workerPoolId"])
+
+    return pools_by_image
+
+
 def get_workers(state=None, **pool_args):
     pools = [p["workerPoolId"] for p in get_pools(**pool_args)]
     workers = []
